function Cat_PreTest(cond)
% =========================================================================
% function Cat_PreTest
%
%% Categorization Test
%
%% Code Authors:
%  Thiago Oliveira da Motta Sampaio (ACESIN/LAPEX/INSERM/NeuroSpin)
%  Virginie van Wassenhove (CEA/NeuroSpin)
% =========================================================================

try
    KbName('UnifyKeyNames');
    escapeKey = KbName('ESCAPE');
    AssertOpenGL;   
    %--------------------------------------------------------------------------
    % - PROMPT USER FOR DATA FILE NAME -
    %--------------------------------------------------------------------------
    dataFile='tmp';
    promptUser=true;
    
    while promptUser
        prompt=inputdlg('ID','Output File',1,{'tmp'});
        if isempty(prompt);
            disp(['Cancel experiment ...']);
            return;
        else
            initials=prompt{1};
        end
        
        tmpFile = [initials,'_iatime.mat'];
        
        if ~exist(tmpFile);
            promptUser = false;
        else
            replace=questdlg(['A data file currently exists. Do you want to replace it?']);
            if strcmp( replace, 'Yes' );
                dataFile = tmpFile;
                promptUser = false;
            end
        end
    end
    %--------------------------------------------------------------------------
	%--------------------------------------------------------------------------
    if strmatch(cond, 'A')
        load([initials, _Trials_Cat_PreTest_params_A.mat'])
        dataFile = [initials,_Cat_PreTest_data_A'];
    else
        display('error: specify condition')
    end
    %--------------------------------------------------------------------------
    % - INITIALIZE DISPLAY -
    %--------------------------------------------------------------------------
    
    % affichage warning/error/autocalibration settings
    Screen('Preference','SkipSyncTests', 0);
    Screen('Preference','VisualDebugLevel', 1);
    Screen('Preference', 'ConserveVRAM', 4096);
    screens = Screen('Screens');
    
    % Size of window: Default to fullscreen:
    screenNumber = 0;
    [w,screenRect] = Screen('OpenWindow', screenNumber,0,[],32,2);

    % blending (pour antialiasing)
    Screen('BlendFunction', w, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
    
    % Display frequency
    fps = Screen('FrameRate',w);      % frames per second
    ifi = Screen('GetFlipInterval', w);
    if fps == 0
        fps = 1/ifi;
    end
    %%
    sH = 19;                                         % screen height (cm)
    sW = 34;                                         % screen width (cm)
    %
    whichScreen = max(Screen('Screens'));
    [w,wRect] = Screen('OpenWindow', whichScreen);
    % color defs
    white = WhiteIndex(w);
    black = BlackIndex(w);
    gray = (white+black)/2;
    red     = [255 0 0 ];
    green   = [0 255 0];
    blue    = [0 0 255];
    yellow  = [255 255 0];
    grayish = [100 100 100];
    ft_color  = white;
    bck_color   = black;
    
    % fixation dot
    % dim + pos defs
    dW = wRect(3) - wRect(1);
    dH = wRect(4) - wRect(2);
    %
    pixel = dH/sH;
    x0 = dW/2;
    y0 = dH/2;
    fix_size = 0.2*pixel;
    fix_pos  = [x0-fix_size/2 y0-fix_size/2 x0+fix_size/2 y0+fix_size/2];
    fix_col  = grayish;
    
    % choice positions TO CHECK
    x1 = x0 - 700; %teste
    x2 = x0 - 400; %teste
    x3 = x0 - 100; %teste
    x4 = x0 + 200; %teste
  
    %
    Screen('FillRect',w, bck_color);
    Screen('Flip', w);
    
    %%
    HideCursor;
    inst1 = 'Pressione ESPAO para continuar';
    inst2 = 'PAUSA';
    inst3 = 'O Experimento terminou. Obrigado pela participao.';
    %
    clear RestrictKeysForKbCheck;
    RestrictKeysForKbCheck([32, 27]);
    Screen('FillRect',w, bck_color);
    Screen('TextFont',w, 'Geneva');
    Screen('TextSize',w, 30);
    Screen('DrawText', w, inst1, x0-100, y0+300, ft_color);
    Screen('FillOval',w, fix_col, fix_pos);
    Screen('Flip', w);
    KbWait;
    
    Screen('FillRect',w, bck_color);
    Screen('FillOval',w, fix_col, fix_pos);
    Screen('Flip', w);
    WaitSecs(1);
    
    % - START LOOP -
    priorityLevel=MaxPriority(w);
    Priority(priorityLevel);
    
    for block = 1:2
        
        % initialize matrice de donnes
        psycdata{block} = [];
        
        if block == 1
            pos1=category1{1};
            pos2=category1{2};
            pos3=category1{3};
            pos4=category1{4};
        elseif block == 2
            pos1=category2{1};
            pos2=category2{2};
            pos3=category2{3};
            pos4=category2{4};
        end
      
        %%%%%%%% TRIALS %%%%%%%% 
        for trial=1:length(expMat{block});     
            t0  = GetSecs; % initialize temps de raction 

              clear RestrictKeysForKbCheck;
              RestrictKeysForKbCheck([27, 32, 49, 50, 51, 52]);            
                Screen('FillOval', w, fix_col, fix_pos);
                [nx, ny, bbox] = DrawFormattedText(w, vlist{expMat{block}(trial,2)}, 'center', 'center', 255);
                screen('DrawText', w, pos1, x1, 200, red);
                screen('DrawText', w, pos2, x2, 200, blue);
                screen('Drawtext', w, pos3, x3, 200, yellow);
                screen('DrawText', w, pos4, x4, 200, green);
                Screen('Flip', w);
            
            % ---------------------- collect response -------------------------
            keyNum      = 0;
            promptUser  = true;
            
            while (promptUser)
                KbWait;
                [keyIsDown,secs,keyCode]=KbCheck;
                
                if keyIsDown ;
                    keyNum = find(keyCode);
                    psycdata{block}(trial,2) = secs-t0; % col 2 RT
                    
                    if keyNum == 49;     % 1
                        psycdata{block}(trial,1) = 1; % col 1 choix
                    elseif keyNum == 50; % 2
                        psycdata{block}(trial,1) = 2; % col 1 choix
                    elseif keyNum == 51; % 3
                        psycdata{block}(trial,1) = 3; % col 1 choix
                    elseif keyNum == 52; % 4
                        psycdata{block}(trial,1) = 4; % col 1 choix
                    elseif  keyCode(escapeKey)
                        error('Esc key was pressed');       % ESCAPE program
                        break;
                    else psycdata{block}(trial,1) = 0 % col 1 choix
                    end
                    promptUser  = false;
                end
            end
            WaitSecs(0.25)
            % ---------------------- collect response -------------------------
               
        end % trial
        
        save(dataFile,'expMat','psycdata');

      if block < 2
        % participant's break time after each block
        Screen('FillRect',w, bck_color);
        Screen('TextFont',w, 'Geneva');
        Screen('TextSize',w, 30);
        Screen('DrawText', w, inst2, x0, y0-100, ft_color);
        Screen('Flip', w);
        WaitSecs(2)
        KbWait;
        Screen('DrawText', w, inst1, x0-100, y0+100, ft_color);
        Screen('FillOval',w, fix_col, fix_pos);
        Screen('Flip', w);
        WaitSecs(2)
        KbWait;
        else 
        Screen('FillRect',w, black);
        Screen('TextFont',w, 'Geneva');
        Screen('TextSize',w, 30);
        Screen('DrawText', w, inst3, x0-150, y0-100, ft_color);
        Screen('Flip', w);
        WaitSecs(3);
      end
    %
            
    end % block
    
    cd DATA_PreTest/
    save(dataFile, 'expMat','psycdata');
    %
    Priority(0);
    ShowCursor;
    clear mex;
    Screen('CloseAll');
    %
catch
    ShowCursor;
    Screen('CloseAll');
    disp(['CRITICAL ERROR: ' lasterr ]);
    disp(['Exiting program ...']);
    rethrow(lasterror);
end